@@ -3,9 +3,9 @@ from datetime import datetime
 from checkout_sdk.common.common import CustomerRequest
 from checkout_sdk.common.common import MarketplaceData
 from checkout_sdk.common.enums import Currency
-from checkout_sdk.payments.payments_previous import BillingInformation
 from checkout_sdk.payments.payments import BillingDescriptor, PaymentType, ShippingDetails, ThreeDsRequest, \
     RiskRequest, PaymentRecipient, ProcessingSettings
+from checkout_sdk.payments.payments_previous import BillingInformation
 
 
 class HostedPaymentsSessionRequest:
@@ -34,4 +34,6 @@ class HostedPaymentsSessionRequest:
     capture_on: datetime
     # Not available on Previous
     processing_channel_id: str
+    # @deprecated marketplace property will be removed in the future, and should be used amount_allocations instead
     marketplace: MarketplaceData
+    amount_allocations: list  # values of AmountAllocations
