@@ -3,9 +3,9 @@ from datetime import datetime
 from checkout_sdk.common.common import CustomerRequest
 from checkout_sdk.common.common import MarketplaceData
 from checkout_sdk.common.enums import Currency
-from checkout_sdk.payments.payments_previous import BillingInformation
 from checkout_sdk.payments.payments import BillingDescriptor, PaymentType, ShippingDetails, ThreeDsRequest, \
     RiskRequest, PaymentRecipient, ProcessingSettings
+from checkout_sdk.payments.payments_previous import BillingInformation
 
 
 class PaymentLinkRequest:
@@ -32,4 +32,6 @@ class PaymentLinkRequest:
     capture: bool
     capture_on: datetime
     processing_channel_id: str
+    # @deprecated marketplace property will be removed in the future, and should be used amount_allocations instead
     marketplace: MarketplaceData
+    amount_allocations: list  # values of AmountAllocations
